==> aliyun-python-sdk-ims-1.0.0.tar.gz: aliyun-python-sdk-ims-1.0.0/aliyunsdkims/request/v20170430/SetSecurityPreferenceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class SetSecurityPreferenceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ims', '2017-04-30', 'SetSecurityPreference','Ims')

	def get_AllowUserToManageAccessKeys(self):
		return self.get_query_params().get('AllowUserToManageAccessKeys')

	def set_AllowUserToManageAccessKeys(self,AllowUserToManageAccessKeys):
		self.add_query_param('AllowUserToManageAccessKeys',AllowUserToManageAccessKeys)

	def get_AllowUserToManageMFADevices(self):
		return self.get_query_params().get('AllowUserToManageMFADevices')

	def set_AllowUserToManageMFADevices(self,AllowUserToManageMFADevices):
		self.add_query_param('AllowUserToManageMFADevices',AllowUserToManageMFADevices)

	def get_EnableSaveMFATicket(self):
		return self.get_query_params().get('EnableSaveMFATicket')

	def set_EnableSaveMFATicket(self,EnableSaveMFATicket):
		self.add_query_param('EnableSaveMFATicket',EnableSaveMFATicket)

	def get_AllowUserToChangePassword(self):
		return self.get_query_params().get('AllowUserToChangePassword')

	def set_AllowUserToChangePassword(self,AllowUserToChangePassword):
		self.add_query_param('AllowUserToChangePassword',AllowUserToChangePassword)

==> aliyun-python-sdk-ims-1.0.1.tar.gz: aliyun-python-sdk-ims-1.0.1/aliyunsdkims/request/v20170430/SetSecurityPreferenceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class SetSecurityPreferenceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ims', '2017-04-30', 'SetSecurityPreference','ims')

	def get_AllowUserToManageAccessKeys(self):
		return self.get_query_params().get('AllowUserToManageAccessKeys')

	def set_AllowUserToManageAccessKeys(self,AllowUserToManageAccessKeys):
		self.add_query_param('AllowUserToManageAccessKeys',AllowUserToManageAccessKeys)

	def get_AllowUserToManageMFADevices(self):
		return self.get_query_params().get('AllowUserToManageMFADevices')

	def set_AllowUserToManageMFADevices(self,AllowUserToManageMFADevices):
		self.add_query_param('AllowUserToManageMFADevices',AllowUserToManageMFADevices)

	def get_EnableSaveMFATicket(self):
		return self.get_query_params().get('EnableSaveMFATicket')

	def set_EnableSaveMFATicket(self,EnableSaveMFATicket):
		self.add_query_param('EnableSaveMFATicket',EnableSaveMFATicket)

	def get_AllowUserToChangePassword(self):
		return self.get_query_params().get('AllowUserToChangePassword')

	def set_AllowUserToChangePassword(self,AllowUserToChangePassword):
		self.add_query_param('AllowUserToChangePassword',AllowUserToChangePassword)
